@@ -1,45 +1,27 @@
 package Devel::Examine::Subs::Engine;
-use 5.008;
+
 use strict;
 use warnings;
 
-our $VERSION = '1.57_01';
-
 use Carp;
 use Data::Dumper;
 use Devel::Examine::Subs;
 use Devel::Examine::Subs::Sub;
 use File::Copy;
+use Tie::File;
 
-BEGIN {
-
-    # we need to do some trickery for DTS due to a circular install
-
-    eval {
-        require Devel::Trace::Subs;
-        import Devel::Trace::Subs qw(trace);
-    };
-
-    if ($@ && ! exists $Devel::Examine::Subs{'trace'}){
-        # override DTS's trace() function if necessary
-        *trace = sub {};
-    }
-};
+our $VERSION = '1.23';
 
 sub new {
-    
-    trace() if $ENV{TRACE};
 
     my $self = {};
     bless $self, shift;
 
-    $self->{engines} = $self->_dt;
+    $self->{engines} = $self->_dt();
 
     return $self;
 }
 sub _dt {
-    
-    trace() if $ENV{TRACE};
 
     my $self = shift;
 
@@ -55,14 +37,12 @@ sub _dt {
         _test => \&_test,
         _test_print => \&_test_print,
         _test_bad => \&_test_bad,
+
     };
 
     return $dt;
 }
 sub exists {
-    
-    trace() if $ENV{TRACE};
-
     my $self = shift;
     my $string = shift;
 
@@ -74,31 +54,20 @@ sub exists {
     }
 }
 sub _test {
-    
-    trace() if $ENV{TRACE};
 
     return sub {
-        trace() if $ENV{TRACE};
         return {a => 1};
     };
 }
 sub _test_print {
-    
-    trace() if $ENV{TRACE};
 
     return sub {
-        
-        trace() if $ENV{TRACE};
         print "Hello, world!\n";
     };
 }
 sub all {
-    
-    trace() if $ENV{TRACE};
 
     return sub {
-        
-        trace() if $ENV{TRACE};
 
         my $p = shift;
         my $struct = shift;
@@ -111,13 +80,9 @@ sub all {
     };
 }
 sub has {
-    
-    trace() if $ENV{TRACE};
 
     return sub {
         
-        trace() if $ENV{TRACE};
-        
         my $p = shift;
         my $struct = shift;
 
@@ -131,12 +96,8 @@ sub has {
     };
 }
 sub missing {
-    
-    trace() if $ENV{TRACE};
 
     return sub {
-        
-        trace() if $ENV{TRACE};
 
         my $p = shift;
         my $struct = shift;
@@ -154,7 +115,7 @@ sub missing {
 
         for my $file (keys %$struct){
             for my $sub (keys %{$struct->{$file}{subs}}){
-                my @code = @{$struct->{$file}{subs}{$sub}{code}};
+                my @code = @{$struct->{$file}{subs}{$sub}{TIE_file_sub}};
 
                 my @clean;
 
@@ -171,13 +132,9 @@ sub missing {
     };
 }
 sub lines {
-    
-    trace() if $ENV{TRACE};
 
     return sub {
         
-        trace() if $ENV{TRACE};
-        
         my $p = shift;
         my $struct = shift;
 
@@ -186,7 +143,7 @@ sub lines {
         for my $file (keys %$struct){
             for my $sub (keys %{$struct->{$file}{subs}}){
                 my $line_num = $struct->{$file}{subs}{$sub}{start};
-                my @code = @{$struct->{$file}{subs}{$sub}{code}};
+                my @code = @{$struct->{$file}{subs}{$sub}{TIE_file_sub}};
                 for my $line (@code){
                     $line_num++;
                     push @{$return{$sub}}, {$line_num => $line};
@@ -197,18 +154,15 @@ sub lines {
     };
 }
 sub objects {
-    
-    trace() if $ENV{TRACE};
 
-    # uses 'subs' post_processor 
+    # uses 'subs' pre_filter
 
     return sub {
-        
-        trace() if $ENV{TRACE};
 
         my $p = shift;
         my $struct = shift;
 
+        my @return;
 
         return if not ref($struct) eq 'ARRAY';
 
@@ -226,15 +180,16 @@ sub objects {
                                             file => $file, 
                                             search => $search
                                         });
-            $lines = $des->lines;
+            $lines = $des->lines();
         }
 
         my $des_sub;
-        my %obj_hash;
-        my @obj_array;
-
+        
         for my $sub (@$struct){
 
+            # if the name of the callback method is mistyped in the
+            # dispatch table, this will be triggered
+
             if ($lines){
                 $sub->{lines_with} = $lines->{$sub->{name}};
             }
@@ -242,220 +197,229 @@ sub objects {
             $des_sub
               = Devel::Examine::Subs::Sub->new($sub, $sub->{name});
 
-            if ($p->{objects_in_hash}){
-                $obj_hash{$sub->{name}} = $des_sub;
-            }
-            else {
-                push @obj_array, $des_sub;
+            #FIXME: this eval catch catches bad dispatch and "not a hashref"
+
+            if ($@){
+                print "dispatch table in engine has a mistyped function value\n\n";
+                confess $@;
             }
+
+            push @return, $des_sub;
         }
 
-        if ($p->{objects_in_hash}){
-            return \%obj_hash;
-        }
-        else {
-            return \@obj_array;
-        }
+        return \@return;
     };
 }
 sub search_replace {
 
-    trace() if $ENV{TRACE};
-
     return sub {
 
-        trace() if $ENV{TRACE};
-
         my $p = shift;
         my $struct = shift;
+        my $des = shift;
 
         my $file = $p->{file};
-        my $exec = $p->{exec};
-
-        my @file_contents;
-
-        if ($p->{file_contents}) {
-            @file_contents = @{ $p->{file_contents} };
+        my $search = $p->{search};
+        
+        if ($search && ! $p->{regex}){
+            $search = "\Q$search";
         }
 
+        my $replace = $p->{replace};
+        my $copy = $p->{copy} if $p->{copy};
+
         if (! $file){
-            croak "\nDevel::Examine::Subs::Engine::search_replace " .
-                  "speaking:\n" .
-                  "can't use search_replace engine without specifying a " .
-                  "file\n\n";
+            croak "\nDevel::Examine::Subs::Engine::search_replace speaking:\n" .
+                  "can't use search_replace engine without specifying a file\n\n";
         }
 
-        if (! $exec || ref($exec) ne 'CODE'){
-            croak "\nDevel::Examine::Subs::Engine::search_replace " .
-                  " speaking:\n" .
-                  "can't use search_replace engine without specifying" .
-                  "a substitution regex code reference\n\n";
+        if (! $search){
+            croak "\nDevel::Examine::Subs::Engine::search_replace speaking:\n" .
+                  "can't use search_replace engine without specifying a search term\n\n";
         }
+        if (! $replace){
+            croak "\nDevel::Examine::Subs::Engine::search_replace speaking:\n" .
+                  "can't use search_replace engine without specifying a replace term\n\n";
+        }
+        
+ 
+        copy $file, "$file.bak";
 
+        if ($copy && -f $copy){
+            unlink $copy;
+        }
+        
+        if ($copy){
+            copy $file, $copy;
+            $file = $copy;
+        }
+       
         my @changed_lines;
         
         for my $sub (@$struct){
+            my $start_line = $sub->start();
+            my $end_line = $sub->end();
 
-            my $start_line = $sub->start;
-            my $end_line = $sub->end;
+            tie my @tie_file, 'Tie::File', $file;
 
             my $line_num = 0;
 
-            for my $line (@file_contents){
-
+            for my $line (@tie_file){
                 $line_num++;
-
                 if ($line_num < $start_line){
                     next;
                 }
                 if ($line_num > $end_line){
                     last;
                 }
-
-                my $orig = $line;
-
-                my $replaced = $exec->($line);
-
-                if ($replaced) {
+                
+                if ($line =~ /$search/){
+                    my $orig = $line;
+                    $line =~ s/$search/$replace/g;
                     push @changed_lines, [$orig, $line];
                 }
             }
+            untie @tie_file;
         }
-
-        $p->{write_file_contents} = \@file_contents;
-
         return \@changed_lines;
     };                        
 }
 sub inject_after {
-    
-    trace() if $ENV{TRACE};
 
     return sub {
-        
-        trace() if $ENV{TRACE};
 
         my $p = shift;
         my $struct = shift;
-
+    
         my $search = $p->{search};
 
-        if ($search && !$p->{regex}) {
+        if ($search && ! $p->{regex}){
             $search = "\Q$search";
         }
 
+        my $num_injects = $p->{injects} // 1;
         my $code = $p->{code};
+        my $copy = $p->{copy};
 
-        if (!$search) {
+        if (! $search){
             croak "\nDevel::Examine::Subs::Engine::inject_after speaking:\n" .
-                "can't use inject_after engine without specifying a " .
-                "search term\n\n";
+                    "can't use inject_after engine without specifying a search term\n\n";
         }
-        if (!$code) {
+        if (! $code){
             croak "\nDevel::Examine::Subs::Engine::inject_after speaking:\n" .
-                "can't use inject_after engine without code to inject\n\n";
+                    "can't use inject_after engine without code to inject\n\n";
 
         }
-
+        
         my $file = $p->{file};
-        my @file_contents = @{$p->{file_contents}};
+ 
+        copy $file, "$file.bak";
 
-        my @processed;
-
-        my $added_lines = 0;
-
-        my @subs;
-
-        for my $sub (@$struct) {
-            push @subs, $sub->name;
+        unlink $copy if -f $copy;
+        
+        if ($copy){
+            copy $file, $copy;
+            $file = $copy;
         }
 
-        my $des = Devel::Examine::Subs->new(file => $p->{file});
-        my $subs_hash = $des->objects(objects_in_hash => 1, include => \@subs);
+        my @unprocessed;       
+        my @processed;
+        
+        for my $sub (@$struct){
+            push @unprocessed, $sub->name();
+        }
 
-        my @sorted_subs = sort {
-                $subs_hash->{$a}->start <=> $subs_hash->{$b}->start
-            } keys %$subs_hash;
+        for my $uname (@unprocessed){
+        
+            my $des = Devel::Examine::Subs->new();
 
-        for (@sorted_subs){
+            my $params = {
+                        file => $file,
+                        pre_filter => 'subs && objects',
+                        pre_filter_return => 2,
+                        search => $search,
+            };
 
-            my $sub = $subs_hash->{$_};
+            my $struct = $des->run($params); 
 
-            my $num_injects = defined $p->{injects} ? $p->{injects} : 1;
+            for my $sub (@$struct){
 
-            push @processed, $sub->name;
+                next unless $sub->name() eq $uname;
 
-            my $start_line = $sub->start;
-            my $end_line = $sub->end;
+                push @processed, $sub->name();
+                
+                my $start_line = $sub->start();
+                my $end_line = $sub->end();
+            
+                tie my @tie_file, 'Tie::File', $file;
 
-            $start_line += $added_lines;
-            $end_line += $added_lines;
 
-            my $line_num = 0;
-            my $new_lines = 0; # don't search added lines
+                my $line_num = 0;
+                my $new_lines = 0; # don't search added lines
 
-            for my $line (@file_contents){
-                $line_num++;
-                if ($line_num < $start_line){
-                    next;
-                }
-                if ($line_num > $end_line){
-                    last;
-                }
+                for my $line (@tie_file){
+                    $line_num++;
 
-                if ($line =~ /$search/ && ! $new_lines){
-
-                    my $location = $line_num;
-
-                    my $indent = '';
-
-                    if (! $p->{no_indent}){
-                        if ($line =~ /^(\s+)/ && $1){
-                            $indent = $1;
-                        }
+                    if ($line_num < $start_line){
+                        next;
                     }
-                    for (@$code){
-                        splice @file_contents, $location++, 0, $indent . $_;
-                        $new_lines++;
-                        $added_lines++;
-                    }
-
-                    # stop injecting after N search finds
-
-                    $num_injects--;
-                    if ($num_injects == 0){
+                    if ($line_num > $end_line){
                         last;
                     }
 
+                    if ($line =~ /$search/ && ! $new_lines){
+                       
+                        my $location = $line_num;
+
+                        my $indent;
+
+                        if (! $p->{no_indent}){
+                            if ($line =~ /^(\s+)/ && $1){
+                                $indent = $1;
+                            }
+                        }
+                        for my $line (@$code){
+                            splice @tie_file, $location++, 0, $indent . $line; 
+                            $new_lines++;
+                            $end_line++;
+                        }
+                        splice @tie_file, $location++, 0, '';
+
+                        # stop injecting after N search finds
+
+                        $num_injects--;
+                        
+                        if ($num_injects == 0){
+                            untie @tie_file;
+                            last;
+                        }
+                        
+                    }
+                    $new_lines-- if $new_lines != 0;
                 }
-                $new_lines-- if $new_lines != 0;
+                untie @tie_file;
             }
         }
-        $p->{write_file_contents} = \@file_contents;
         return \@processed;
     };                        
 }
 1;
-
 sub _vim_placeholder {}
 
 __END__
 
 =head1 NAME
 
-Devel::Examine::Subs::Engine - Provides core engine callbacks for
-Devel::Examine::Subs
+Devel::Examine::Subs::Engine - Provides core engine callbacks for Devel::Examine::Subs
 
 =head1 SYNOPSIS
 
     use Devel::Examine::Subs::Engine;
 
-    my $compiler = Devel::Examine::Subs::Engine->new;
-
-    my $engine = 'has';
+    my $compiler = Devel::Examine::Subs::Engine->new();
 
     if (! $compiler->exists($engine)){
-        croak "engine $engine is not implemented.\n";
+        croak "engine '$engine' is not implemented.\n";
     }
 
     eval {
@@ -465,52 +429,49 @@ Devel::Examine::Subs
 
 =head1 METHODS
 
-All methods other than C<exists()> takes an href of configuration data as its
-first parameter.
+All methods other than C<exists()> takes an href of configuration data as it's first parameter.
 
 =head2 C<exists('engine')>
 
-Verifies whether the engine name specified as the string parameter exists and
-is valid.
+Verifies whether the engine name specified as the string parameter exists and is valid.
 
-=head2 C<all>
+=head2 C<all()>
 
 Takes C<$struct> params directly from the Processor module.
 
 Returns an aref.
 
-=head2 C<has>
+=head2 C<has()>
 
-Takes C<$struct> from the output of the 'file_lines_contain' Postprocessor.
+Takes C<$struct> from the output of the 'file_lines_contain' Pre-filter.
 
 Returns an aref.
 
-=head2 C<missing>
+=head2 C<missing()>
 
 Data comes directly from the Processor.
 
 Returns an aref.
 
-=head2 C<lines>
+=head2 C<lines()>
 
-The module that passes data in is dependant on whether 'search' is set.
-Otherwise, it comes directly from the Processor.
+The module that passes data in is dependant on whether 'search' is set. Otherwise, it comes directly from the Processor.
 
 Returns an href.
 
-=head2 C<objects>
+=head2 C<objects()>
 
 Uses C<Devel::Examine::Subs::Sub> to generate objects based on subs.
 
 Returns an aref of said objects.
 
-=head2 C<search_replace>
+=head2 C<search_replace()>
 
 Takes params, struct and a des object.
 
 Returns aref of replaced lines if there are any.
 
-=head2 C<inject_after>
+=head2 C<inject_after()>
 
 Returns aref of subs that had code injected.
 
@@ -528,9 +489,8 @@ You can find documentation for this module with the perldoc command.
 
 Copyright 2015 Steve Bertrand.
 
-This program is free software; you can redistribute it and/or modify it under
-the terms of either: the GNU General Public License as published by the Free
-Software Foundation; or the Artistic License.
+This program is free software; you can redistribute it and/or modify it under the terms of either: the GNU General Public License as 
+published by the Free Software Foundation; or the Artistic License.
 
 See http://dev.perl.org/licenses/ for more information.
 
