@@ -1,30 +1,13 @@
 package Devel::Examine::Subs::Prefilter;
-use 5.012;
 use strict;
 use warnings;
 
-our $VERSION = '1.44_02';
-
 use Carp;
 use Data::Dumper;
 
-BEGIN {
-
-    # we need to do some trickery for DTS due to a circular install
-
-    eval {
-        require Devel::Trace::Subs;
-        import Devel::Trace::Subs qw(trace);
-    };
-
-    if ($@){
-        *trace = sub {};
-    }
-};
+our $VERSION = '1.23';
 
 sub new {
-    
-    trace() if $ENV{TRACE};
 
     my $self = {};
     bless $self, shift;
@@ -36,8 +19,6 @@ sub new {
     return $self;
 }
 sub _dt {
-    
-    trace() if $ENV{TRACE};
 
     my $self = shift;
 
@@ -54,9 +35,6 @@ sub _dt {
     return $dt;
 }
 sub exists {
-    
-    trace() if $ENV{TRACE};
-
     my $self = shift;
     my $string = shift;
 
@@ -69,11 +47,7 @@ sub exists {
 }
 sub subs {
     
-    trace() if $ENV{TRACE};
-    
     return sub {
-        
-        trace() if $ENV{TRACE};
 
         my $p = shift;
         my $struct = shift;
@@ -97,7 +71,7 @@ sub subs {
                 $s->{$f}{subs}{$sub}{start}++;
                 $s->{$f}{subs}{$sub}{end}++;
                 $s->{$f}{subs}{$sub}{name} = $sub;
-                @{ $s->{$f}{subs}{$sub}{file} } = @{ $s->{$f}{contents} };
+                @{ $s->{$f}{subs}{$sub}{file} } = @{ $s->{$f}{TIE_file} };
                 push @subs, $s->{$f}{subs}{$sub};
             }
         }
@@ -105,12 +79,8 @@ sub subs {
     };
 }
 sub file_lines_contain {
-    
-    trace() if $ENV{TRACE};
 
     return sub {
-        
-        trace() if $ENV{TRACE};
 
         my $p = shift;
         my $struct = shift;
@@ -131,7 +101,7 @@ sub file_lines_contain {
             for my $sub (keys %{$s->{$f}{subs}}){
                 my $found = 0;
                 my @has;
-                for (@{$s->{$f}{subs}{$sub}{contents}}){
+                for (@{$s->{$f}{subs}{$sub}{TIE_file_sub}}){
                     if ($_ and /$search/){
                         $found++;
                         push @has, $_;
@@ -141,7 +111,7 @@ sub file_lines_contain {
                     delete $s->{$f}{subs}{$sub};                
                     next;
                 }
-                $s->{$f}{subs}{$sub}{contents} = \@has;
+                $s->{$f}{subs}{$sub}{TIE_file_sub} = \@has;
             }
         }
         return $struct;
@@ -149,12 +119,8 @@ sub file_lines_contain {
 }
 sub end_of_last_sub {
     
-    trace() if $ENV{TRACE};
-    
     return sub {
         
-        trace() if $ENV{TRACE};
-        
         my $p = shift;
         my $struct = shift;
 
@@ -171,26 +137,17 @@ sub end_of_last_sub {
     };
 }
 sub _test {
-    
-    trace() if $ENV{TRACE};
 
     return sub {
-        
-        trace() if $ENV{TRACE};
-        my $p = shift;
         my $struct = shift;
         return $struct;
     };
 }
 sub objects {
-    
-    trace() if $ENV{TRACE};
 
     # uses 'subs' pre_filter
 
     return sub {
-        
-        trace() if $ENV{TRACE};
 
         my $p = shift;
         my $struct = shift;
@@ -221,8 +178,7 @@ sub objects {
             #FIXME: this eval catch catches bad dispatch and "not a hashref"
 
             if ($@){
-                print "dispatch table in engine has a mistyped function " .
-                      "value\n\n";
+                print "dispatch table in engine has a mistyped function value\n\n";
                 confess $@;
             }
 
@@ -239,30 +195,25 @@ __END__
 
 =head1 NAME
 
-Devel::Examine::Subs::Prefilter - Provides core Pre-Filter callbacks for
-Devel::Examine::Subs
+Devel::Examine::Subs::Prefilter - Provides core Pre-Filter callbacks for Devel::Examine::Subs
 
 =head1 DESCRIPTION
 
-This module generates and supplies the core prefilter module callbacks.
-Prefilters run after the core Processor, and before any Engine is run.
+This module generates and supplies the core prefilter module callbacks. Prefilters run after the core Processor, and before any Engine is run.
 
 =head1 SYNOPSIS
 
-Pre-filters can be daisy chained as text strings that represent a built-in
-prefilter, or as callbacks, or both.
+Pre-filters can be daisy chained as text strings that represent a built-in prefilter, or as callbacks, or both.
 
 See C<Devel::Examine::Subs::_pre_filter()> for implementation details.
 
 =head1 METHODS
 
-All methods other than C<exists()> takes an href of configuration data as its
-first parameter.
+All methods other than C<exists()> takes an href of configuration data as it's first parameter.
 
 =head2 C<exists('prefilter')>
 
-Verifies whether the prefilter name specified as the string parameter exists
-and is valid.
+Verifies whether the prefilter name specified as the string parameter exists and is valid.
 
 =head2 C<subs()>
 
@@ -271,8 +222,7 @@ Returns an aref of hash refs, each containing info per sub.
 
 =head2 C<file_lines_contain()>
 
-Returns an aref similar to C<subs()>, but includes an array within each sub
-href that contains lines that match a search term.
+Returns an aref similar to C<subs()>, but includes an array within each sub href that contains lines that match a search term.
 
 =head2 C<end_of_last_sub()>
 
@@ -294,9 +244,8 @@ You can find documentation for this module with the perldoc command.
 
 Copyright 2015 Steve Bertrand.
 
-This program is free software; you can redistribute it and/or modify it under
-the terms of either: the GNU General Public License as published by the Free
-Software Foundation; or the Artistic License.
+This program is free software; you can redistribute it and/or modify it under the terms of either: the GNU General Public License as 
+published by the Free Software Foundation; or the Artistic License.
 
 See http://dev.perl.org/licenses/ for more information.
 
