@@ -1,29 +1,13 @@
 package Devel::Examine::Subs::Sub;
-use 5.008;
+
 use strict;
 use warnings;
 
-our $VERSION = '1.57_01';
-
 use Data::Dumper;
 
-BEGIN {
-
-    # we need to do some trickery for DTS due to a circular install
-
-    eval {
-        require Devel::Trace::Subs;
-        import Devel::Trace::Subs qw(trace);
-    };
-
-    if ($@ && ! exists $Devel::Examine::Subs{'trace'}){
-        *trace = sub {};
-    }
-};
+our $VERSION = '1.23';
 
 sub new {
-    
-    trace() if $ENV{TRACE};
 
     my $class = shift;
     my $data = shift;
@@ -37,36 +21,22 @@ sub new {
     return $self;
 }
 sub name {
-    
-    trace() if $ENV{TRACE};
-    
     my $self = shift;
     return $self->{data}{name};
 }
 sub start {
-    
-    trace() if $ENV{TRACE};
-    
     my $self = shift;
     return $self->{data}{start};
 }
 sub end {
-    
-    trace() if $ENV{TRACE};
-    
     my $self = shift;
     return $self->{data}{end};
 }
 sub line_count {
-    
-    trace() if $ENV{TRACE};
-    
     my $self = shift;
     return $self->{data}{num_lines};
 }
 sub lines {
-    
-    trace() if $ENV{TRACE};
 
     my $self = shift;
 
@@ -85,12 +55,10 @@ sub lines {
     return \@line_linenum;
 }
 sub code {
-    
-    trace() if $ENV{TRACE};
 
     my $self = shift;
 
-    my $code = $self->{data}{code};
+    my $code = $self->{data}{TIE_file_sub};
 
     return $code;
 }
